// Enhanced constellation animation
class ConstellationCanvas {
  constructor() {
    this.canvas = document.getElementById('constellation');
    this.ctx = this.canvas.getContext('2d');
    this.particles = [];
    this.properties = {
      bgColor: 'rgba(15, 5, 36, 0)',
      particleColor: 'rgba(199, 125, 255, 0.6)',
      particleRadius: 1.5,
      particleCount: 100,
      particleMaxVelocity: 0.5,
      lineLength: 150,
      particleLife: 6
    };
    
    this.init();
    this.bindEvents();
  }

  init() {
    this.resizeCanvas();
    this.createParticles();
    this.animate();
  }

  bindEvents() {
    window.addEventListener('resize', () => this.resizeCanvas());
  }

  resizeCanvas() {
    this.canvas.width = window.innerWidth;
    this.canvas.height = window.innerHeight;
  }

  createParticles() {
    for (let i = 0; i < this.properties.particleCount; i++) {
      this.particles.push(new Particle(this.canvas, this.properties));
    }
  }

  animate() {
    this.ctx.clearRect(0, 0, this.canvas.width, this.canvas.height);
    this.particles.forEach(particle => {
      particle.update();
      particle.draw(this.ctx);
    });
    this.drawLines();
    requestAnimationFrame(() => this.animate());
  }

  drawLines() {
    for (let i = 0; i < this.particles.length; i++) {
      for (let j = i + 1; j < this.particles.length; j++) {
        const dx = this.particles[i].x - this.particles[j].x;
        const dy = this.particles[i].y - this.particles[j].y;
        const distance = Math.sqrt(dx * dx + dy * dy);

        if (distance < this.properties.lineLength) {
          const opacity = 1 - (distance / this.properties.lineLength);
          this.ctx.beginPath();
          this.ctx.strokeStyle = `rgba(199, 125, 255, ${opacity})`;
          this.ctx.lineWidth = 0.5;
          this.ctx.moveTo(this.particles[i].x, this.particles[i].y);
          this.ctx.lineTo(this.particles[j].x, this.particles[j].y);
          this.ctx.stroke();
        }
      }
    }
  }
}

class Particle {
  constructor(canvas, properties) {
    this.canvas = canvas;
    this.properties = properties;
    this.reset();
  }

  reset() {
    this.x = Math.random() * this.canvas.width;
    this.y = Math.random() * this.canvas.height;
    this.velocityX = Math.random() * (this.properties.particleMaxVelocity * 2) - this.properties.particleMaxVelocity;
    this.velocityY = Math.random() * (this.properties.particleMaxVelocity * 2) - this.properties.particleMaxVelocity;
    this.life = Math.random() * this.properties.particleLife * 60;
  }

  update() {
    this.x += this.velocityX;
    this.y += this.velocityY;

    if (this.x < 0 || this.x > this.canvas.width) this.velocityX *= -1;
    if (this.y < 0 || this.y > this.canvas.height) this.velocityY *= -1;

    this.life--;
    if (this.life < 1) this.reset();
  }

  draw(ctx) {
    ctx.beginPath();
    ctx.arc(this.x, this.y, this.properties.particleRadius, 0, Math.PI * 2);
    ctx.fillStyle = this.properties.particleColor;
    ctx.fill();
  }
}

// Initialize constellation effect
document.addEventListener('DOMContentLoaded', () => {
  new ConstellationCanvas();
});
